==> japhar-0.08.tar.gz: japhar-0.08/lib/libjvmdi/src/jvmdifld.c <==
/* -*- Mode: C; c-file-style: "gnu" -*-
   jvmdifld.c -- JVMDI Field Information Functions
   Created: Hernan Otero <hernan_otero@bigfoot.com>, 18-Jul-1998.
 */
/*
  This file is part of Japhar, the GNU Virtual Machine for Java Bytecodes.
  Japhar is a project of The Hungry Programmers, GNU, and OryxSoft.

  Copyright (C) 1998, 1999 The Hungry Programmers

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "jvmdiint.h"
#include "interp.h"
#include "objects.h"
#include <assert.h>

#include <assert.h>
#include <stdlib.h>

JNIEXPORT jvmdiError JNICALL
JVMDI_GetFieldName(JNIEnv *env, jclass clazz, jfieldID field, 
                   char **namePtr, char **signaturePtr)
{
  jstring name = NULL, signature = NULL;

  /* the usual NULL check. */
  if (env == NULL
      || namePtr == NULL
      || signaturePtr == NULL)
    return JVMDI_ERROR_NULL_POINTER;

  if (clazz == NULL)
    return JVMDI_ERROR_INVALID_CLASS;

  if (field == NULL)
    return JVMDI_ERROR_INVALID_FIELDID;

  name = (*env)->NewStringUTF(env, field->name);
  signature = (*env)->NewStringUTF(env, field->sig_str);

  if (name == NULL
      || signature == NULL)
    {
      /* how do we free things?  it doesn't make sense to have the
	 same thread local objects for jvmdi methods like the JNI spec
	 does for native methods, does it?  I suppose, since these
	 objects were not changed into global refs, then they should
	 be collected the next time around, so we shouldn't worry. */
      return JVMDI_ERROR_OUT_OF_MEMORY;
    }

  *namePtr = name;
  *signaturePtr = signature;
  return JVMDI_ERROR_NONE;
}

JNIEXPORT jvmdiError JNICALL
JVMDI_GetFieldDeclaringClass(JNIEnv *env, jclass clazz, jfieldID field,
 			     jclass *declaringClassPtr)
{
  /* the usual NULL check. */
  if (env == NULL
      || declaringClassPtr == NULL)
    return JVMDI_ERROR_NULL_POINTER;

  if (clazz == NULL)
    return JVMDI_ERROR_INVALID_CLASS;

  if (field == NULL)
    return JVMDI_ERROR_INVALID_FIELDID;

  *declaringClassPtr = field->clazz;
  return JVMDI_ERROR_NONE;
}

JNIEXPORT jvmdiError JNICALL
JVMDI_GetFieldModifiers(JNIEnv *env, jclass clazz, jfieldID field,
                        jint *modifiersPtr)
{
  /* the usual NULL check. */
  if (env == NULL
      || modifiersPtr == NULL)
    return JVMDI_ERROR_NULL_POINTER;

  if (clazz == NULL)
    return JVMDI_ERROR_INVALID_CLASS;

  if (field == NULL)
    return JVMDI_ERROR_INVALID_FIELDID;

  *modifiersPtr = field->access_flags;
  return JVMDI_ERROR_NONE;
}

==> japhar-0.11.tar.gz: japhar-0.11/lib/libjvmdi/src/jvmdifld.c <==
/* -*- Mode: C; c-file-style: "gnu" -*-
   jvmdifld.c -- JVMDI Field Information Functions
   Created: Hernan Otero <hernan_otero@bigfoot.com>, 18-Jul-1998.
 */
/*
  This file is part of Japhar, the GNU Virtual Machine for Java Bytecodes.
  Japhar is a project of The Hungry Programmers, GNU, and OryxSoft.

  Copyright (C) 1998, 1999 The Hungry Programmers

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "jvmdiint.h"

JNIEXPORT jvmdiError JNICALL
JVMDI_GetFieldName(JNIEnv *env, jclass clazz, jfieldID field, 
                   char **namePtr, char **signaturePtr)
{
  /* the usual NULL check. */
  if (env == NULL
      || namePtr == NULL
      || signaturePtr == NULL)
    return JVMDI_ERROR_NULL_POINTER;

  if (clazz == NULL)
    return JVMDI_ERROR_INVALID_CLASS;

  if (field == NULL)
    return JVMDI_ERROR_INVALID_FIELDID;

  *namePtr = field->name;
  *signaturePtr = field->sig_str;
  return JVMDI_ERROR_NONE;
}

JNIEXPORT jvmdiError JNICALL
JVMDI_GetFieldDeclaringClass(JNIEnv *env, jclass clazz, jfieldID field,
 			     jclass *declaringClassPtr)
{
  HungryEnv *henv = HVM_ThreadGetEnv();

  /* the usual NULL check. */
  if (env == NULL
      || declaringClassPtr == NULL)
    return JVMDI_ERROR_NULL_POINTER;

  if (clazz == NULL)
    return JVMDI_ERROR_INVALID_CLASS;

  if (field == NULL)
    return JVMDI_ERROR_INVALID_FIELDID;

  *declaringClassPtr = clazzfile_to_jclass(henv, field->clazz);
  return JVMDI_ERROR_NONE;
}

JNIEXPORT jvmdiError JNICALL
JVMDI_GetFieldModifiers(JNIEnv *env, jclass clazz, jfieldID field,
                        jint *modifiersPtr)
{
  /* the usual NULL check. */
  if (env == NULL
      || modifiersPtr == NULL)
    return JVMDI_ERROR_NULL_POINTER;

  if (clazz == NULL)
    return JVMDI_ERROR_INVALID_CLASS;

  if (field == NULL)
    return JVMDI_ERROR_INVALID_FIELDID;

  *modifiersPtr = field->access_flags;
  return JVMDI_ERROR_NONE;
}
